import {request} from "@/api/request";


export interface RecordData {
  key: string
  value: number
}

export interface CourseDepData {
  chapters: Chapters[]
  course: Curriculum
  hours: Hours
  /** 是否必修 */
  is_required: boolean
  learn_hour_records: LearnHourRecords
  learn_record: LearnRecord | null
}

export interface HourPlayData {
  /** 时间 */
  duration: number
  /** 格式 */
  extension: string
  /** 地址 */
  url: string
}

export interface Course {
  courses: Curriculum[]
  learn_course_records: unknown
  user_course_hour_count: unknown
  stats: CueStats
}

export const curriculum = {
  use() {
    return request<Manage[]>('/api/v1/user/all', 'GET')
  },
  /** 学习记录 */
  record(id: number) {
    return request<RecordData[]>(`/api/v1/user/record/${id}`, "GET")
  },
  /** 查看课程课时数据 */
  courseDep(id: number, depId: number | null) {
    return request<CourseDepData>(`/api/v1/course/${id}${depId ? `/dep/${depId}` : ''}`, "GET")
  },
  hourPlay(courseId: number, id: number) {
    return request<HourPlayData>(`/api/v1/course/${courseId}/hour/${id}/play`, "GET")
  },
  /** 删除课程 */
  delCur(dep_id: number, course_id: number) {
    return request(`/api/v1/department/assign/${dep_id}?course_id=${course_id}`, "DELETE")
  },
  /** 部门课程进度 */
  course() {
    return request<Course>(`/api/v1/user/courses`, "GET")
  },
  /** 课程结束 */
  curEnd(courseId: number, id: number, duration: number) {
    return request(`/api/v1/course/${courseId}/hour/${id}/record`, "POST", {duration})
  }
}
