import {BaseEventOrig, Video, VideoProps} from "@tarojs/components";
import {HVideoOptions} from "@/components/video/type";
import Taro from "@tarojs/taro";
import {FC, useState} from "react";
import {Profile} from '@/store'

const deviation: number = 0.5

const HVideo: FC<HVideoOptions> = (opt: HVideoOptions) => {
  const {user} = Profile.useContainer()
  const video = Taro.createVideoContext('video')
  const [currentTime, setCurrentTime] = useState(0)

  function onTimeUpdate(event: BaseEventOrig<VideoProps.onTimeUpdateEventDetail>) {
    if (opt.preview) return;
    if (user?.role_type !== 0) return;
    const time = event.detail.currentTime
    /** 前进回退 */
    if (currentTime + deviation < time) {
      video.seek(currentTime)
      return
    }
    setCurrentTime(time)

    /** 判断是否进入断点 */
    opt.breakpoint.forEach(d => {
      if (time < d.time + deviation && time > d.time - deviation) {
        opt.onBreakpoint(d.id)
        video.pause()
        video.seek(d.time - deviation)
        return
      }
    })
  }

  function onEnded() {
    console.log(user)
    if (user?.role_type !== 0) return;
    if (currentTime + 1 > opt.duration) {
      opt.onEnded()
    } else {
      video.seek(currentTime)
      video.play()
    }
  }

  return (
    <>
      <Video
        id='video'
        style={'width:100%'}
        poster={opt.poster}
        src={opt.src}
        enableProgressGesture={false}
        direction={90}
        onTimeUpdate={onTimeUpdate}
        onEnded={onEnded}
      />
    </>
  )
}

export default HVideo
