import {CustomWrapper, PageContainer, ScrollView} from "@tarojs/components";
import {useEffect, useState} from "react";
import HVideo from "@/components/video/video";
import {getCurrentInstance} from "@tarojs/runtime";
import {curriculum, HourPlayData} from "@/api";
import {Profile} from '@/store'
import Taro from "@tarojs/taro";

const Course = () => {
  const {courseId, id, preview} = getCurrentInstance()?.router?.params as {
    courseId: number,
    id: number,
    preview: string | null
  }
  const [breakpoint, setBreakpoint] = useState<any[]>([])
  const [show, setShow] = useState(false)
  const [data, setData] = useState<HourPlayData | null>(null)

  async function onEnded() {
    try {
      await curriculum.curEnd(courseId, id, data?.duration || 0)
      Taro.showModal({title: "学习完成"})
    } catch (e) {
    }
  }

  function onBreakpoint(id: number) {
    setBreakpoint(breakpoint.filter(d => d.id != id))
    setShow(true)
  }

  async function getData() {
    const res = await curriculum.hourPlay(courseId, id)
    if (res) {
      setData(res)
    }
  }

  useEffect(() => {
    getData()
  }, [])

  return (
    <CustomWrapper>
      <Profile.Provider>
        {data && <HVideo
          duration={data?.duration}
          preview={!!preview}
          src={data?.url || ''}
          onEnded={onEnded}
          breakpoint={breakpoint}
          onBreakpoint={onBreakpoint}
        />}


        <view>
          <PageContainer
            show={show}
            position='bottom'
            round
          >
            <ScrollView
              style='height:70vh'
              scrollY
              scrollTop={0}
              scrollWithAnimation
            >
            </ScrollView>
          </PageContainer>
        </view>
      </Profile.Provider>
    </CustomWrapper>
  )
}
export default Course
