import {FC, useEffect, useState} from "react";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import {View} from "@tarojs/components";
import {Profile} from '@/store'
import {CourseDepData} from "@/api";
import Collapse from "@/components/collapse/collapse";
import Hours from "@/pages/business/videoInfo/components/hours";
import Taro from "@tarojs/taro";

interface Props {
  data: CourseDepData | null
}

const Catalogue: FC<Props> = ({data}: Props) => {
  const {user} = Profile.useContainer()
  const [current, setCurrent] = useState(1)
  const [tabList, setTabList] = useState<TabList[]>([
    {title: '介绍', value: 0},
    {title: '目录', value: 1},
    {title: '评价', value: 2},
  ])

  useEffect(() => {
    if (user?.role_type && user?.role_type > 0) {
      setTabList([...tabList, {title: '学员管理', value: 3}])
    }
  }, [])

  function tabChange({tab}: OnChangOpt) {
    setCurrent(tab?.value as number)
  }

  function getHors(chapter_id: number): Hour[] | null {
    for (const d of Object.values(data?.hours || {})) {
      if (d[0].chapter_id === chapter_id) {
        return d
      }
    }
    return null
  }


  function complete(id: number): boolean {
    return !!data?.learn_hour_records[id]?.is_finished
  }


  function jump(id) {
    Taro.navigateTo({url: `/pages/business/course/course?courseId=${data?.course.id}&id=${id}`})
  }


  return (
    <View className='catalogue'>
      <Tabs tabList={tabList} onChange={tabChange} current={current}/>
      <View className='py-2'>
        {current === 0 && <View className='short_desc'>{data?.course.short_desc}</View>}
        {current === 1 && <View>
          <View className='font-weight'>课程目录</View>
          {data?.chapters.length ? Object.values(data?.chapters || {}).map((d, index) => <View>
              <Collapse title={`${index + 1}.${d.name}`}>
                <>
                  {getHors(d.id)?.map((hor, index) => <Hours
                      id={hor.id}
                      index={index}
                      title={hor.title}
                      duration={hor.duration}
                      complete={complete}
                      click={jump}
                    />
                  )}
                </>
              </Collapse>
            </View>)
            : data?.hours?.[0].map((hor, index) => <Hours
                id={hor.id}
                index={index}
                title={hor.title}
                duration={hor.duration}
                complete={complete}
                click={jump}
              />
            )}
        </View>}
        {current === 2 && <View className='text-center'>评论暂未开放</View>}
      </View>
    </View>
  )
}

export default Catalogue
