import {Image, Text, View} from "@tarojs/components";
import {FC, useState} from "react";
import {getCurrentInstance} from "@tarojs/runtime";
import {CourseDepData, curriculum} from "@/api";
import './videoInfo.scss'
import Taro from "@tarojs/taro";
import {Profile} from '@/store'
import Catalogue from "@/pages/business/videoInfo/components/catalogue";

const VideoInfo: FC = () => {
  const {id, depId} = getCurrentInstance()?.router?.params as { id: number, depId: number | null }
  const [data, setData] = useState<CourseDepData | null>(null)

  async function getData() {
    const res = await curriculum.courseDep(id, depId)
    if (res) {
      setData(res)
    }
  }

  Taro.useDidShow(getData)


  return (
    <Profile.Provider>
      <View className='content'>
        <Image src={data?.course.thumb || ''} className='image' mode='scaleToFill'/>

        {/*<ContainDeps cur_id={id} name={data?.course.title}/>*/}

        <View className='header'>
          <View className='flex justify-between text-muted'>
            <Text className='font-34 text-warning'>{data?.is_required ? '必修' : '选秀'}</Text>
            <Text>{data?.course.class_hour}课时</Text>
          </View>
          <View className='font-weight font-40 my-4'>{data?.course.title}</View>
          <View className='text-muted font-26'>
            {/*<Text className='mr-3'>时长：32:10</Text>*/}
            <Text>学习进度{data?.learn_record?.finished_count || 0}/{data?.learn_record?.hour_count || Object.keys(data?.hours || {}).length}</Text>
          </View>
        </View>

        <Catalogue data={data}/>
      </View>
    </Profile.Provider>
  )
}

export default VideoInfo
