import {FC, useState} from "react";
import Taro from "@tarojs/taro";
import {View} from "@tarojs/components";
import {CoursesKey, Cur, publicApi} from "@/api/public";
import VideoCover from "@/components/videoCover/videoCover";
import styles from '../index.module.scss'

interface Props {
  categoryId: CoursesKey
}

export const VideoList: FC<Props> = ({categoryId}: Props) => {
  const [data, setDta] = useState<Cur[] | null>(null)

  async function getData() {
    const res = await publicApi.curs()
    setDta(res)
  }


  Taro.useDidShow(() => {
    getData()
  })

  function rateOfLearning(id: number, class_hour: number): JSX.Element {
    console.log(id)
    return (<View>{`共${class_hour}节/已学${0}节`}</View>)
  }

  return (
    <>
      {data?.map(d => (
        <>{
          d.courses?.[categoryId].length ? <View>
            <View className='font-weight'>{d.name}</View>
            <View className={'py-2 flex justify-between flex-wrap ' + styles.videoListBox}>
              {d.courses[categoryId].map(d => (
                <VideoCover
                  thumb={d.thumb}
                  title={d.title}
                  id={d.id}
                  depId={d.id}
                  content={rateOfLearning(d.id, d.class_hour)}
                />
              ))}
            </View>
          </View> : null
        }</>
      ))}
    </>
  )
}
