import {CustomWrapper, View} from "@tarojs/components";
import {getCurrentInstance} from "@tarojs/runtime";
import {ManageApi} from "@/api/manage";
import React, {FC, useEffect, useState} from "react";
import Tabs, {TabList} from "@/components/tabs/tabs";
import {Category, publicApi} from "@/api/public";
import Taro from "@tarojs/taro";
import VideoCover from "@/components/videoCover/videoCover";

interface AddProps {
  cur_id: number,
  name: string,
  index: number
}

const AddCur = () => {
  const {id} = getCurrentInstance()?.router?.params as { id: string }
  const [category, setCategory] = useState<TabList[]>([])
  const [categoryId, setCategoryId] = useState<number>(0)
  const [dataMap, setDataMap] = useState<Map<number, Curriculum[]>>(new Map())


  async function getCategory() {
    try {
      const data: (TabList)[] = []
      const {categories} = await publicApi.category()
      Object.values(categories).map(d => {
        data.push(...d.map<TabList<Category>>(c => ({title: c.name, value: c.id})))
      })
      setCategory(data)
      setCategoryId(data[0].value as number)
    } catch (e) {
    }
  }


  async function getData() {
    if (categoryId !== null) {
      const res = await ManageApi.optionalCur(Number(id), categoryId)
      const map = new Map(dataMap)
      const data = map.get(categoryId)
      if (!data) {
        map.delete(categoryId)
        map.set(categoryId, res)
        setDataMap(map)
      } else {
        res.forEach(d => {
          const index = data.findIndex(c => c.id === d.id)
          if (index === -1) {
            data.push(d)
          } else {
            data.splice(index, 1, d)
          }
        })
        map.delete(categoryId)
        map.set(categoryId, data)
        setDataMap(map)
      }
    }
  }

  const Add: FC<AddProps> = ({cur_id, name, index}: AddProps) => {
    function addCur() {
      function required() {
        Taro.showModal({
          title: '课程是否为必修',
          cancelText: '选修',
          confirmText: '必修',
          async success({confirm}) {
            try {
              const is_required = confirm ? 1 : 0
              Taro.showLoading()
              await ManageApi.addCur({course_id: [cur_id], dep_id: [Number(id)], is_required})
              const map = new Map(dataMap)
              const data = map.get(categoryId!) || []
              if (data) {
                data.splice(index, 1)
              }
              map.delete(categoryId!)
              map.set(categoryId!, data)
              setDataMap(map)
              Taro.showToast({title: "添加成功"})
            } catch (e) {
            }
            Taro.hideLoading()
          }
        })
      }

      Taro.showModal({
        title: '确定添加' + name,
        success({confirm}) {
          confirm && required()
        }
      })
    }

    return (
      <View className='text-center mt-1' onClick={addCur}>添加课程</View>
    )
  }

  useEffect(() => {
    getCategory().then()
  }, [])

  useEffect(() => {
    getData().then()
  }, [categoryId])
  return (
    <CustomWrapper>
      <View className='bg-white'>
        <Tabs tabList={category} onChange={(data) => setCategoryId(data.tab?.value as number)} current={categoryId}/>
      </View>
      {
        (categoryId && dataMap.get(categoryId)?.length) ?
          <View className='bg-white mt-2 py-2 flex flex-wrap'>
            {dataMap.get(categoryId)?.map((d, index) => (
              <VideoCover
                key={d.id}
                thumb={d.thumb}
                title={<Add cur_id={d.id} name={d.title} index={index}/>}
                id={d.id}
                depId={Number(id)}
                content={d.title}
              />
            ))}
          </View>
          : null
      }

      <View className='text-center mt-3'>- 暂无更多 -</View>
    </CustomWrapper>
  )
}

export default AddCur
