import {Button, CustomWrapper, Image, Text, View} from "@tarojs/components";
import {curriculum} from "@/api";
import {FC, useState} from "react";
import Taro, {useDidShow} from "@tarojs/taro";
import Tabs, {OnChangOpt, TabList} from "@/components/tabs/tabs";
import './student.scss'
import {Profile} from '@/store'
import {ManageApi} from "@/api/manage";

interface RoleTypeProps {
  id: number
  role_type: number
  getData: () => Promise<void>
}

const RoleType: FC<RoleTypeProps> = ({id, role_type, getData}: RoleTypeProps) => {
  const {user} = Profile.useContainer()

  function setRoleType() {
    if (role_type === 2) {
      Taro.showModal({title: "禁止修改超级管理员"})
      return
    }
    const type = role_type === 0 ? 1 : 0
    Taro.showModal({
      title: "设置为" + ['学员', '管理员'][type],
      async success({confirm}) {
        if (confirm) {
          try {
            Taro.showLoading()
            await ManageApi.setRoleType(id, {auth_id: user?.id!, role_type: type})
            Taro.hideLoading()
            Taro.showToast({title: "设置成功"})
            await getData()
          } catch (e) {
          }
        }
      }
    })
  }

  return (user?.role_type === 2 ?
    <View onClick={setRoleType}>{['设置管理员', '设置学员', '超级管理员'][role_type]}</View>
    : null)
}

const studentAdmin = () => {
  const [list, setList] = useState<TabList[]>([])
  const [user, setUser] = useState<ManageUsers[]>([])

  async function getData() {
    Taro.showLoading()
    const res = await curriculum.use()
    if (res) {
      setList(res.map(d => ({title: d.name, value: d})))
      setUser(res[0].users)
    }
    Taro.hideLoading()
  }

  useDidShow(getData)


  function listClick(data: OnChangOpt) {
    setUser((data.tab?.value as Manage).users)
  }

  function jumCollege(id: number, name: string) {
    Taro.navigateTo({url: `/pages/manage/college/college?id=${id}&name=${name}`})
  }

  function changeStudent(id?: number) {
    Taro.navigateTo({url: "/pages/manage/addStudent/addStudent" + (id ? `?id=${id}` : '')})
  }

  function del(id: number) {
    Taro.showModal({
      title: '是否确认删除',
      async success({confirm}) {
        if (confirm) {
          await ManageApi.del(id)
          Taro.showToast({title: '删除成功'})
          await getData()
        }
      }
    })
  }


  return (
    <CustomWrapper>
      <Profile.Provider>
        <View className='bg-white mb-3'>
          <Tabs tabList={list} onChange={listClick}/>
        </View>
        {user.length ? user.map((d) => (
            <View className='bg-white user'>
              <View className='flex mt-3 header p-2 justify-between'>
                <View className='flex'>
                  <View className='lock'
                        style={`background:${['#73c057', '#c94f4f'][d.is_lock]}`}>{['正常', '警用'][d.is_lock]}</View>
                  <Text>学员编号 {d.id}</Text>
                </View>
                <View className='del' onClick={() => del(d.id)}>删除</View>
              </View>
              <View className='p-2 flex info justify-between'>
                <View>
                  <View className='font-weight my-3'>{d.name}</View>
                  <View className='flex mb-3'>
                    <View style='width:60px' className='text-muted'>类型</View>
                    <View>{['学员', '管理员', '超级管理员'][d.role_type]}</View>
                  </View>
                  <View className='flex mb-3'>
                    <View style='width:60px' className='text-muted'>手机号</View>
                    <View>{d.phone_number}</View>
                  </View>
                  <View className='flex mb-3'>
                    <View style='width:60px' className='text-muted'>邮箱</View>
                    <View>{d.email}</View>
                  </View>
                </View>
                <Image src={d.avatar} mode='widthFix'/>
              </View>
              <View className='flex justify-between p-2 operation'>
                <View onClick={() => changeStudent(d.id)}>修改</View>
                <View onClick={() => jumCollege(d.id, d.name)}>学习记录</View>
                <RoleType id={d.id} role_type={d.role_type} getData={getData}/>
              </View>
            </View>
          ))
          : <View className='text-center'>暂无数据</View>}

        <View className='py-8'/>

        <Button className='add' onClick={() => changeStudent()}>新建学员</Button>
      </Profile.Provider>
    </CustomWrapper>
  )
}
export default studentAdmin
