import {CustomWrapper, Image, Text, View} from "@tarojs/components";
import {FC, useEffect, useState} from "react";
import {getCurrentInstance} from "@tarojs/runtime";
import Taro, {useReachBottom} from "@tarojs/taro";
import {CurLearningRecord, ManageApi} from "@/api/manage";
import '@/pages/manage/studentAdmin/student.scss'

const StudentRecord: FC = () => {
  const [page, setPage] = useState(1)
  const {cur_id, name} = getCurrentInstance()?.router?.params as { cur_id: string, name: string }
  const [data, setData] = useState<CurLearningRecord | null>(null)
  const [total, setTotal] = useState(0)

  async function getData() {
    try {
      const res = await ManageApi.curLearningRecord(cur_id, {page, size: 10})
      if (!data) {
        setData(res)
      } else {
        const oldData: CurLearningRecord = JSON.parse(JSON.stringify(data))
        oldData.data.push(...res.data)
        oldData.departments = res.departments
        Object.entries(res.user_dep_ids).forEach(([key, value]) => {
          oldData.user_dep_ids[key] = value
        })
        Object.entries(res.user_course_records).forEach(([key, value]) => {
          oldData.user_course_records[key] = value
        })
        Object.entries(res.user_course_hour_user_first_at).forEach(([key, value]) => {
          oldData.user_course_hour_user_first_at[key] = value
        })
        setData(oldData)
      }
      setTotal(res.total)
    } catch (e) {
    }
  }

  function getDep(user_id: number): string {
    const cur_ids = data?.user_dep_ids[user_id]
    if (cur_ids) {
      return cur_ids.map(d => data?.departments[d]).join('、')
    }
    return ''
  }

  useReachBottom(() => {
    if (data && data.data.length < total) {
      setPage(page + 1)
    }
  })


  useEffect(() => {
    getData()
  }, [page])
  Taro.setNavigationBarTitle({title: name})

  return (
    <CustomWrapper>
      {data?.data.map(d => (
        <View className='bg-white user'>
          <View className='flex mt-3 header p-2 justify-between'>
            <View className='flex'>
              <Text>学员编号 {d.id}</Text>
            </View>
          </View>
          <View className='p-2 flex info justify-between'>
            <View>
              <View className='font-weight my-3'>{d.name}</View>
              <View className='flex mb-3'>
                <View style='width:80px' className='text-muted'>类型</View>
                <View>{['学员', '管理员', '超级管理员'][d.role_type]}</View>
              </View>
              <View className='flex mb-3'>
                <View style='width:80px' className='text-muted'>手机号</View>
                <View>{d.phone_number}</View>
              </View>
              <View className='flex mb-3'>
                <View style='width:80px' className='text-muted'>邮箱</View>
                <View>{d.email}</View>
              </View>
              <View className='flex mb-3'>
                <View style='width:80px' className='text-muted'>部门</View>
                <View>{getDep(d.id)}</View>
              </View>
              <View className='flex mb-3'>
                <View style='width:80px' className='text-muted'>学习进度</View>
                <View>{data?.user_course_records[d.id]?.finished_count || 0}/{data?.course.class_hour}</View>
              </View>
            </View>
            <Image src={d.avatar} mode='widthFix'/>
          </View>
          <View className='flex justify-between p-2 operation'>
          </View>
        </View>
      ))}
    </CustomWrapper>
  )
}

export default StudentRecord
